@@ -20,8 +20,9 @@ def init_celery(app: Flask) -> Celery:
 
 
 def decide_on_run(fn):
-    def wrapper(*args):
+    def wrapper(*args, priority=None):
         should_use_worker = current_app.config['USE_WORKER']
+        fn.priority = priority
         if should_use_worker:
             return fn.delay(*args)
         else:
